import { useToken } from "@ant-design/pro-components";
import { Col, Row, Spin, Image } from "antd";
import { useEffect, useRef, useState } from "react";

function ReadText(props: { next: (data: { pageNum: number, pageSize: number, id: number }) => Promise<any>, data: any }) {
    let { next, data } = props;
    const divRef = useRef<HTMLDivElement>(null);
    const [isFetching, setIsFetching] = useState(true);
    const [newData, setNewData] = useState<any>(null);
    let {token} = useToken()
    console.log(data)
    // 存放首次的size
    useEffect(() => {
        setNewData(data);
    }, []);

    useEffect(() => {
        const handleKeyDown = (event: KeyboardEvent) => {
            if (divRef.current) {
                if (event.key === "ArrowDown") {
                    divRef.current.scrollBy(0, 50);
                } else if (event.key === "ArrowUp") {
                    divRef.current.scrollBy(0, -50);
                }
            }
        };

        window.addEventListener("keydown", handleKeyDown);

        return () => {
            window.removeEventListener("keydown", handleKeyDown);
        };
    }, []);

    const handleScroll = () => {
        if (divRef.current) {
            const { scrollTop, scrollHeight, clientHeight } = divRef.current;
            if (scrollTop + clientHeight >= scrollHeight / 2 && isFetching) {
                if (newData.current * newData.size < newData.total) {
                    getText();
                }
            }
            if (scrollTop + clientHeight >= scrollHeight) {
                console.log("到底了");
                getText();
            }
        }
    };

    async function getText() {
        if (newData.current * newData.size < newData.total) {
            setIsFetching(false);
            console.log("还有内容");
            let r = await next({ ...data, pageNum: 1, pageSize: newData.size + data.size }); // Replace with actual data
            setNewData(r);
            setIsFetching(true);
        }
    }

    return (
        data && <div
            style={{ height: '90vh', overflow: 'hidden', display: 'flex', justifyContent: 'space-around' }}
        >
            <div style={{ width: '20%', flexFlow: 'column', alignItems: 'center', display: 'flex', borderRight: '1px solid #efefef' }}>
                <Image src={data?.picUrl} style={{ width: 150, marginBottom: 20, marginTop: 20 }} />
                <Row style={{ width: '80%' }} gutter={[10, 5]}>
                    <Col span={24} style={{ fontSize: 14, color:token.colorTextSecondary }}><span style={{ color: token. colorText }}><span>作者</span>：</span>{data?.authorInfo?.authorName}</Col>
                    <Col span={24} style={{ fontSize: 14, color:token.colorTextSecondary }}><span style={{ color: token. colorText  }}><span>类别</span>：</span>{data?.categoryInfo?.name}</Col>
                    <Col span={24} style={{ fontSize: 14, color:token.colorTextSecondary }}><span style={{ color: token. colorText  }}><span>来源</span>：</span>{({ "UPLOAD": "管理员", "CREATOR": "创作者" } as any)[data.source]}</Col>
                    <Col span={24} style={{ fontSize: 14, color:token.colorTextSecondary }}><span style={{ color: token. colorText  }}><span>频道</span>：</span>{data?.corpUserName == 0 ? "男频" : "女频"}</Col>
                    <Col span={24} style={{ fontSize: 14, color:token.colorTextSecondary }}><span style={{ color: token. colorText  }}>标签：</span> {
                        data?.labelInfoList?.map((tags: { id: string, name: string }, index: number) => {
                            return tags?.name
                        }).join(',')
                    }</Col>
                    <Col span={24} style={{ fontSize: 14, color:token.colorTextSecondary }} ><span style={{ color: token. colorText  }}><span>状态</span>：</span>{["连载中", "已完结"][data.bookStatus]}</Col>
                    <Col span={24} style={{ fontSize: 14, color:token.colorTextSecondary }}><span style={{ color: token. colorText  }}>评分：</span>{data?.score || 0}</Col>
                    <Col span={24} style={{ fontSize: 14, color:token.colorTextSecondary }}><span style={{ color: token. colorText  }}>点击量：</span>{data?.visitCount || 0}</Col>
                    <Col span={24} style={{ fontSize: 14, color:token.colorTextSecondary }}><span style={{ color: token. colorText  }}>总字数：</span>{data?.wordCount || 0}</Col>
                    <Col span={24} style={{ fontSize: 14, color:token.colorTextSecondary }}><span style={{ color: token. colorText  }}>上架状态：</span>{["上架中", "已下架"][data.shelveStatus]}</Col>
                    <Col span={24} style={{ fontSize: 14, color:token.colorTextSecondary }}><span style={{ color: token. colorText  }}>描述：</span>{data?.bookDesc}</Col>

                </Row>
            </div>
            <div
                style={{ overflowY: 'auto', display: 'flex', flexFlow: "column", width: '75%', paddingBottom: 50, boxSizing: 'border-box' }}
                onScroll={handleScroll}
                ref={divRef}
            >
                <Spin spinning={!data?.size}>
                    {
                        newData?.records?.map((item: { shortBookContentVO: { contentId: number, content: string } }) => {
                            return <div style={{ fontSize: 17, lineHeight: 2 }} key={item.shortBookContentVO.contentId} dangerouslySetInnerHTML={{ __html: item.shortBookContentVO.content.replace(/\n/g, '<br/>') }}></div>
                        })
                    }
                </Spin>
            </div>
        </div>
    );
}

export default ReadText;
